Documentation
¶
Index ¶
- Variables
- type AnalysisConfig
- type AnalyzerCustom
- func (c AnalyzerCustom) WithCharFilter(value []AnalyzerCustomCharFilter) AnalyzerCustomProperties
- func (c AnalyzerCustom) WithFilter(value []AnalyzerCustomFilter) AnalyzerCustomProperties
- func (c AnalyzerCustom) WithPositionIncrementGap(value int) AnalyzerCustomProperties
- func (c AnalyzerCustom) WithTokenizer(value AnalyzerCustomTokenizer) AnalyzerCustomProperties
- type AnalyzerCustomCharFilter
- type AnalyzerCustomFilter
- type AnalyzerCustomProperties
- type AnalyzerCustomTokenizer
- type AnalyzerFingerprint
- func (f AnalyzerFingerprint) WithMaxOutputSize(value int) AnalyzerFingerprintProperties
- func (f AnalyzerFingerprint) WithSeparator(value string) AnalyzerFingerprintProperties
- func (f AnalyzerFingerprint) WithStopwords(value []string) AnalyzerFingerprintProperties
- func (f AnalyzerFingerprint) WithStopwordsPath(value string) AnalyzerFingerprintProperties
- type AnalyzerFingerprintProperties
- type AnalyzerFunc
- type AnalyzerKeyword
- type AnalyzerLanguage
- type AnalyzerLanguageLanguage
- type AnalyzerLanguageProperties
- type AnalyzerPattern
- func (p AnalyzerPattern) WithFlags(value []AnalyzerPatternFlags) AnalyzerPatternProperties
- func (p AnalyzerPattern) WithLowercase(enable bool) AnalyzerPatternProperties
- func (p AnalyzerPattern) WithPattern(value AnalyzerPatternPattern) AnalyzerPatternProperties
- func (p AnalyzerPattern) WithStopwords(value []string) AnalyzerPatternProperties
- func (p AnalyzerPattern) WithStopwordsPath(value string) AnalyzerPatternProperties
- type AnalyzerPatternFlags
- type AnalyzerPatternPattern
- type AnalyzerPatternProperties
- type AnalyzerSimple
- type AnalyzerStandard
- type AnalyzerStandardProperties
- type AnalyzerStop
- type AnalyzerStopProperties
- type AnalyzerWhitespace
- type Config
- type DefinitionConfig
- type Fake
- type FakeBoolean
- type FakeByte
- type FakeDates
- type FakeDouble
- type FakeFloats
- type FakeHalfFloat
- type FakeIP
- type FakeInteger
- type FakeLong
- type FakeScaledFloat
- type FakeShort
- type FieldBoolean
- type FieldBooleanProperties
- type FieldByte
- func (b FieldByte) WithCoerce(enabled bool) FieldByteProperties
- func (b FieldByte) WithDocValues(enabled bool) FieldByteProperties
- func (b FieldByte) WithIgnoreMalformed(enabled bool) FieldByteProperties
- func (b FieldByte) WithIndex(enabled bool) FieldByteProperties
- func (b FieldByte) WithNullValue(value int) FieldByteProperties
- func (b FieldByte) WithStore(enabled bool) FieldByteProperties
- type FieldByteProperties
- type FieldDate
- func (d FieldDate) WithDocValues(enabled bool) FieldDateProperties
- func (d FieldDate) WithFormat(value string) FieldDateProperties
- func (d FieldDate) WithIgnoreMalformed(enabled bool) FieldDateProperties
- func (d FieldDate) WithIndex(enabled bool) FieldDateProperties
- func (d FieldDate) WithStore(enabled bool) FieldDateProperties
- type FieldDateProperties
- type FieldDouble
- func (d FieldDouble) WithCoerce(enabled bool) FieldDoubleProperties
- func (d FieldDouble) WithDocValues(enabled bool) FieldDoubleProperties
- func (d FieldDouble) WithIgnoreMalformed(enabled bool) FieldDoubleProperties
- func (d FieldDouble) WithIndex(enabled bool) FieldDoubleProperties
- func (d FieldDouble) WithNullValue(value int) FieldDoubleProperties
- func (d FieldDouble) WithStore(enabled bool) FieldDoubleProperties
- type FieldDoubleProperties
- type FieldFloat
- func (f FieldFloat) WithCoerce(enabled bool) FieldFloatProperties
- func (f FieldFloat) WithDocValues(enabled bool) FieldFloatProperties
- func (f FieldFloat) WithIgnoreMalformed(enabled bool) FieldFloatProperties
- func (f FieldFloat) WithIndex(enabled bool) FieldFloatProperties
- func (f FieldFloat) WithNullValue(value int) FieldFloatProperties
- func (f FieldFloat) WithStore(enabled bool) FieldFloatProperties
- type FieldFloatProperties
- type FieldFunc
- type FieldHalfFloat
- func (h FieldHalfFloat) WithCoerce(enabled bool) FieldHalfFloatProperties
- func (h FieldHalfFloat) WithDocValues(enabled bool) FieldHalfFloatProperties
- func (h FieldHalfFloat) WithIgnoreMalformed(enabled bool) FieldHalfFloatProperties
- func (h FieldHalfFloat) WithIndex(enabled bool) FieldHalfFloatProperties
- func (h FieldHalfFloat) WithNullValue(value int) FieldHalfFloatProperties
- func (h FieldHalfFloat) WithStore(enabled bool) FieldHalfFloatProperties
- type FieldHalfFloatProperties
- type FieldIP
- type FieldIPProperties
- type FieldInteger
- func (i FieldInteger) WithCoerce(enabled bool) FieldIntegerProperties
- func (i FieldInteger) WithDocValues(enabled bool) FieldIntegerProperties
- func (i FieldInteger) WithIgnoreMalformed(enabled bool) FieldIntegerProperties
- func (i FieldInteger) WithIndex(enabled bool) FieldIntegerProperties
- func (i FieldInteger) WithNullValue(value int) FieldIntegerProperties
- func (i FieldInteger) WithStore(enabled bool) FieldIntegerProperties
- type FieldIntegerProperties
- type FieldKeyword
- func (k FieldKeyword) WithDocValues(enabled bool) FieldKeywordProperties
- func (k FieldKeyword) WithEagerGlobalOrdinals(enabled bool) FieldKeywordProperties
- func (k FieldKeyword) WithIgnoreAbove(value int) FieldKeywordProperties
- func (k FieldKeyword) WithIndex(enabled bool) FieldKeywordProperties
- func (k FieldKeyword) WithNormalizer(value string) FieldKeywordProperties
- func (k FieldKeyword) WithNullValue(value string) FieldKeywordProperties
- func (k FieldKeyword) WithStore(enabled bool) FieldKeywordProperties
- type FieldKeywordProperties
- type FieldLong
- func (l FieldLong) WithCoerce(enabled bool) FieldLongProperties
- func (l FieldLong) WithDocValues(enabled bool) FieldLongProperties
- func (l FieldLong) WithIgnoreMalformed(enabled bool) FieldLongProperties
- func (l FieldLong) WithIndex(enabled bool) FieldLongProperties
- func (l FieldLong) WithNullValue(value int) FieldLongProperties
- func (l FieldLong) WithStore(enabled bool) FieldLongProperties
- type FieldLongProperties
- type FieldScaledFloat
- func (s FieldScaledFloat) WithCoerce(enabled bool) FieldScaledFloatProperties
- func (s FieldScaledFloat) WithDocValues(enabled bool) FieldScaledFloatProperties
- func (s FieldScaledFloat) WithIgnoreMalformed(enabled bool) FieldScaledFloatProperties
- func (s FieldScaledFloat) WithIndex(enabled bool) FieldScaledFloatProperties
- func (s FieldScaledFloat) WithNullValue(value int) FieldScaledFloatProperties
- func (s FieldScaledFloat) WithStore(enabled bool) FieldScaledFloatProperties
- type FieldScaledFloatProperties
- type FieldShort
- func (s FieldShort) WithCoerce(enabled bool) FieldShortProperties
- func (s FieldShort) WithDocValues(enabled bool) FieldShortProperties
- func (s FieldShort) WithIgnoreMalformed(enabled bool) FieldShortProperties
- func (s FieldShort) WithIndex(enabled bool) FieldShortProperties
- func (s FieldShort) WithNullValue(value int) FieldShortProperties
- func (s FieldShort) WithStore(enabled bool) FieldShortProperties
- type FieldShortProperties
- type FieldText
- func (t FieldText) WithAnalyzer(value string) FieldTextProperties
- func (t FieldText) WithEagerGlobalOrdinals(enabled bool) FieldTextProperties
- func (t FieldText) WithIndex(enabled bool) FieldTextProperties
- func (t FieldText) WithNorms(enabled bool) FieldTextProperties
- func (t FieldText) WithPositionIncrementGap(value int) FieldTextProperties
- func (t FieldText) WithSearchAnalyzer(value string) FieldTextProperties
- func (t FieldText) WithStore(enabled bool) FieldTextProperties
- func (t FieldText) WithTermVector(value string) FieldTextProperties
- type FieldTextProperties
- type IndexFunc
- type LocationFromFile
- type LocationGenerate
- type M
- type MappingsConfig
- type NormalizerCustom
- type NormalizerCustomCharFilter
- type NormalizerCustomFilter
- type NormalizerCustomProperties
- type NormalizerFunc
- type OriginFunc
- type SettingsConfig
- type Temp
Constants ¶
This section is empty.
Variables ¶
var ( ErrClientBadConnection = fmt.Errorf("elasticsearch client: failed to establish a connection") ErrClientCreatingIndex = fmt.Errorf("elasticsearch client: failed to create index") ErrClientCreatingDocuments = fmt.Errorf("elasticsearch client: bulk insert operation failed") ErrClientDeletingIndex = fmt.Errorf("elasticsearch client: failed to delete index") ErrClientDeletingDocuments = fmt.Errorf("elasticsearch client: failed to delete documents by query") ErrMigratorMigratingIndex = fmt.Errorf("migrator: index operation failed during migration process") ErrMigratorDocuments = fmt.Errorf("migrator: document operation failed during migration process") ErrPorterMigratingUp = fmt.Errorf("porter: failed to perform 'up' migration") ErrPorterMigratingDown = fmt.Errorf("porter: failed to perform 'down' migration") )
var (
ErrOriginFromFile = fmt.Errorf("origin: failed to read documents from file")
)
Functions ¶
This section is empty.
Types ¶
type AnalysisConfig ¶
type AnalysisConfig struct {
Analyzer map[string]interface{} `json:"analyzer,omitempty"`
Normalizer map[string]interface{} `json:"normalizer,omitempty"`
}
AnalysisConfig{} holds custom analysis settings for the Elasticsearch index, including analyzers and normalizers to control text processing during indexing and searching.
type AnalyzerCustom ¶
type AnalyzerCustom func(name string, properties ...AnalyzerCustomProperties) AnalyzerFunc
func (AnalyzerCustom) WithCharFilter ¶
func (c AnalyzerCustom) WithCharFilter(value []AnalyzerCustomCharFilter) AnalyzerCustomProperties
WithCharFilter() adds one or more character filters to a custom analyzer.
func (AnalyzerCustom) WithFilter ¶
func (c AnalyzerCustom) WithFilter(value []AnalyzerCustomFilter) AnalyzerCustomProperties
WithFilter() sets the list of token filters to apply to the output of the tokenizer.
func (AnalyzerCustom) WithPositionIncrementGap ¶
func (c AnalyzerCustom) WithPositionIncrementGap(value int) AnalyzerCustomProperties
WithPositionIncrementGap() sets the position increment gap.
func (AnalyzerCustom) WithTokenizer ¶
func (c AnalyzerCustom) WithTokenizer(value AnalyzerCustomTokenizer) AnalyzerCustomProperties
WithTokenizer() sets the tokenizer for a custom analyzer.
type AnalyzerCustomCharFilter ¶
type AnalyzerCustomCharFilter string
AnalyzerCustomCharFilter defines character filters that modify text before tokenization.
var ( AnalyzerCustomCharFilterHTMLStrip AnalyzerCustomCharFilter = "html_strip" AnalyzerCustomCharFilterMapping AnalyzerCustomCharFilter = "mapping" AnalyzerCustomCharFilterPatternReplace AnalyzerCustomCharFilter = "pattern_replace" )
type AnalyzerCustomFilter ¶
type AnalyzerCustomFilter string
AnalyzerCustomFilter defines token filters that modify or enhance token streams after tokenization.
var ( AnalyzerCustomFilterApostrophe AnalyzerCustomFilter = "apostrophe" AnalyzerCustomFilterASCIIFolding AnalyzerCustomFilter = "asciifolding" AnalyzerCustomFilterCJKBigram AnalyzerCustomFilter = "cjk_bigram" AnalyzerCustomFilterCJKWidth AnalyzerCustomFilter = "cjk_width" AnalyzerCustomFilterClassic AnalyzerCustomFilter = "classic" AnalyzerCustomFilterCommonGrams AnalyzerCustomFilter = "common_grams" AnalyzerCustomFilterConditional AnalyzerCustomFilter = "condition" AnalyzerCustomFilterDecimalDigit AnalyzerCustomFilter = "decimal_digit" AnalyzerCustomFilterDelimitedPayload AnalyzerCustomFilter = "delimited_payload" AnalyzerCustomFilterDictionaryDecompound AnalyzerCustomFilter = "dictionary_decompounder" AnalyzerCustomFilterEdgeNGram AnalyzerCustomFilter = "edge_ngram" AnalyzerCustomFilterElision AnalyzerCustomFilter = "elision" AnalyzerCustomFilterFingerprint AnalyzerCustomFilter = "fingerprint" AnalyzerCustomFilterFlattenGraph AnalyzerCustomFilter = "flatten_graph" AnalyzerCustomFilterHunspell AnalyzerCustomFilter = "hunspell" AnalyzerCustomFilterHyphenationDecompound AnalyzerCustomFilter = "hyphenation_decompounder" AnalyzerCustomFilterKeepTypes AnalyzerCustomFilter = "keep_types" AnalyzerCustomFilterKeepWords AnalyzerCustomFilter = "keep_words" AnalyzerCustomFilterKeywordMarker AnalyzerCustomFilter = "keyword_marker" AnalyzerCustomFilterKeywordRepeat AnalyzerCustomFilter = "keyword_repeat" AnalyzerCustomFilterKStem AnalyzerCustomFilter = "kstem" AnalyzerCustomFilterLength AnalyzerCustomFilter = "length" AnalyzerCustomFilterLimitTokenCount AnalyzerCustomFilter = "limit" AnalyzerCustomFilterLowercase AnalyzerCustomFilter = "lowercase" AnalyzerCustomFilterMinHash AnalyzerCustomFilter = "min_hash" AnalyzerCustomFilterMultiplexer AnalyzerCustomFilter = "multiplexer" AnalyzerCustomFilterNGram AnalyzerCustomFilter = "ngram" AnalyzerCustomFilterNormalization AnalyzerCustomFilter = "normalization" AnalyzerCustomFilterPatternCapture AnalyzerCustomFilter = "pattern_capture" AnalyzerCustomFilterPatternReplace AnalyzerCustomFilter = "pattern_replace" AnalyzerCustomFilterPhonetic AnalyzerCustomFilter = "phonetic" AnalyzerCustomFilterPorterStem AnalyzerCustomFilter = "porter_stem" AnalyzerCustomFilterPredicateScript AnalyzerCustomFilter = "predicate_script" AnalyzerCustomFilterRemoveDuplicates AnalyzerCustomFilter = "remove_duplicates" AnalyzerCustomFilterReverse AnalyzerCustomFilter = "reverse" AnalyzerCustomFilterShingle AnalyzerCustomFilter = "shingle" AnalyzerCustomFilterSnowball AnalyzerCustomFilter = "snowball" AnalyzerCustomFilterStemmer AnalyzerCustomFilter = "stemmer" AnalyzerCustomFilterStemmerOverride AnalyzerCustomFilter = "stemmer_override" AnalyzerCustomFilterStop AnalyzerCustomFilter = "stop" AnalyzerCustomFilterSynonym AnalyzerCustomFilter = "synonym" AnalyzerCustomFilterSynonymGraph AnalyzerCustomFilter = "synonym_graph" AnalyzerCustomFilterTrim AnalyzerCustomFilter = "trim" AnalyzerCustomFilterTruncate AnalyzerCustomFilter = "truncate" AnalyzerCustomFilterUnique AnalyzerCustomFilter = "unique" AnalyzerCustomFilterUppercase AnalyzerCustomFilter = "uppercase" AnalyzerCustomFilterWordDelimiter AnalyzerCustomFilter = "word_delimiter" AnalyzerCustomFilterWordDelimiterGraph AnalyzerCustomFilter = "word_delimiter_graph" )
type AnalyzerCustomProperties ¶
type AnalyzerCustomProperties func() map[string]interface{}
type AnalyzerCustomTokenizer ¶
type AnalyzerCustomTokenizer string
AnalyzerCustomTokenizer defines available tokenizer types for custom analyzers.
var ( AnalyzerCustomTokenizerStandard AnalyzerCustomTokenizer = "standard" AnalyzerCustomTokenizerLetter AnalyzerCustomTokenizer = "letter" AnalyzerCustomTokenizerLowercase AnalyzerCustomTokenizer = "lowercase" AnalyzerCustomTokenizerWhitespace AnalyzerCustomTokenizer = "whitespace" AnalyzerCustomTokenizerUAXURLEmail AnalyzerCustomTokenizer = "uax_url_email" AnalyzerCustomTokenizerClassic AnalyzerCustomTokenizer = "classic" AnalyzerCustomTokenizerThai AnalyzerCustomTokenizer = "thai" AnalyzerCustomTokenizerNGram AnalyzerCustomTokenizer = "ngram" AnalyzerCustomTokenizerEdgeNGram AnalyzerCustomTokenizer = "edge_ngram" AnalyzerCustomTokenizerKeyword AnalyzerCustomTokenizer = "keyword" AnalyzerCustomTokenizerPattern AnalyzerCustomTokenizer = "pattern" AnalyzerCustomTokenizerSimplePattern AnalyzerCustomTokenizer = "simple_pattern" AnalyzerCustomTokenizerCharGroup AnalyzerCustomTokenizer = "char_group" AnalyzerCustomTokenizerSimplePatternSplit AnalyzerCustomTokenizer = "simple_pattern_split" AnalyzerCustomTokenizerPathHierarchy AnalyzerCustomTokenizer = "path_hierarchy" )
type AnalyzerFingerprint ¶
type AnalyzerFingerprint func(name string, properties ...AnalyzerFingerprintProperties) AnalyzerFunc
func (AnalyzerFingerprint) WithMaxOutputSize ¶
func (f AnalyzerFingerprint) WithMaxOutputSize(value int) AnalyzerFingerprintProperties
WithMaxOutputSize() sets max length of the resulting fingerprint string.
func (AnalyzerFingerprint) WithSeparator ¶
func (f AnalyzerFingerprint) WithSeparator(value string) AnalyzerFingerprintProperties
WithSeparator() sets the string used to join tokens into a fingerprint.
func (AnalyzerFingerprint) WithStopwords ¶
func (f AnalyzerFingerprint) WithStopwords(value []string) AnalyzerFingerprintProperties
WithStopwords() sets the stopwords for the standard analyzer.
func (AnalyzerFingerprint) WithStopwordsPath ¶
func (f AnalyzerFingerprint) WithStopwordsPath(value string) AnalyzerFingerprintProperties
WithStopwordsPath() sets an external stopwords file path.
type AnalyzerFingerprintProperties ¶
type AnalyzerFingerprintProperties func() map[string]interface{}
type AnalyzerFunc ¶
type AnalyzerFunc func() map[string]interface{}
type AnalyzerKeyword ¶
type AnalyzerKeyword func(name string) AnalyzerFunc
type AnalyzerLanguage ¶
type AnalyzerLanguage func(name string, language AnalyzerLanguageLanguage, properties ...AnalyzerLanguageProperties) AnalyzerFunc
func (AnalyzerLanguage) WithStemExclusion ¶
func (l AnalyzerLanguage) WithStemExclusion(value []string) AnalyzerLanguageProperties
WithStemExclusion() defines a list of terms that should not be stemmed during analysis.
func (AnalyzerLanguage) WithStopwords ¶
func (l AnalyzerLanguage) WithStopwords(value []string) AnalyzerLanguageProperties
WithStopwords() sets the stopwords for the standard analyzer.
func (AnalyzerLanguage) WithStopwordsPath ¶
func (l AnalyzerLanguage) WithStopwordsPath(value string) AnalyzerLanguageProperties
WithStopwordsPath() sets an external stopwords file path.
type AnalyzerLanguageLanguage ¶
type AnalyzerLanguageLanguage string
AnalyzerLanguageLanguage defines language-specific analyzers provided by Elasticsearch.
var ( AnalyzerLanguageArabic AnalyzerLanguageLanguage = "arabic" AnalyzerLanguageArmenian AnalyzerLanguageLanguage = "armenian" AnalyzerLanguageBasque AnalyzerLanguageLanguage = "basque" AnalyzerLanguageBengali AnalyzerLanguageLanguage = "bengali" AnalyzerLanguageBrazilian AnalyzerLanguageLanguage = "brazilian" AnalyzerLanguageBulgarian AnalyzerLanguageLanguage = "bulgarian" AnalyzerLanguageCatalan AnalyzerLanguageLanguage = "catalan" AnalyzerLanguageCJK AnalyzerLanguageLanguage = "cjk" AnalyzerLanguageCzech AnalyzerLanguageLanguage = "czech" AnalyzerLanguageDanish AnalyzerLanguageLanguage = "danish" AnalyzerLanguageDutch AnalyzerLanguageLanguage = "dutch" AnalyzerLanguageEnglish AnalyzerLanguageLanguage = "english" AnalyzerLanguageEstonian AnalyzerLanguageLanguage = "estonian" AnalyzerLanguageFinnish AnalyzerLanguageLanguage = "finnish" AnalyzerLanguageFrench AnalyzerLanguageLanguage = "french" AnalyzerLanguageGalician AnalyzerLanguageLanguage = "galician" AnalyzerLanguageGerman AnalyzerLanguageLanguage = "german" AnalyzerLanguageGreek AnalyzerLanguageLanguage = "greek" AnalyzerLanguageHindi AnalyzerLanguageLanguage = "hindi" AnalyzerLanguageHungarian AnalyzerLanguageLanguage = "hungarian" AnalyzerLanguageIndonesian AnalyzerLanguageLanguage = "indonesian" AnalyzerLanguageIrish AnalyzerLanguageLanguage = "irish" AnalyzerLanguageItalian AnalyzerLanguageLanguage = "italian" AnalyzerLanguageLatvian AnalyzerLanguageLanguage = "latvian" AnalyzerLanguageLithuanian AnalyzerLanguageLanguage = "lithuanian" AnalyzerLanguageNorwegian AnalyzerLanguageLanguage = "norwegian" AnalyzerLanguagePersian AnalyzerLanguageLanguage = "persian" AnalyzerLanguagePortuguese AnalyzerLanguageLanguage = "portuguese" AnalyzerLanguageRomanian AnalyzerLanguageLanguage = "romanian" AnalyzerLanguageRussian AnalyzerLanguageLanguage = "russian" AnalyzerLanguageSerbian AnalyzerLanguageLanguage = "serbian" AnalyzerLanguageSorani AnalyzerLanguageLanguage = "sorani" AnalyzerLanguageSpanish AnalyzerLanguageLanguage = "spanish" AnalyzerLanguageSwedish AnalyzerLanguageLanguage = "swedish" AnalyzerLanguageTurkish AnalyzerLanguageLanguage = "turkish" AnalyzerLanguageThai AnalyzerLanguageLanguage = "thai" )
type AnalyzerLanguageProperties ¶
type AnalyzerLanguageProperties func() map[string]interface{}
type AnalyzerPattern ¶
type AnalyzerPattern func(name string, properties ...AnalyzerPatternProperties) AnalyzerFunc
func (AnalyzerPattern) WithFlags ¶
func (p AnalyzerPattern) WithFlags(value []AnalyzerPatternFlags) AnalyzerPatternProperties
WithFlags() configures regex flags (e.g., CASE_INSENSITIVE).
func (AnalyzerPattern) WithLowercase ¶
func (p AnalyzerPattern) WithLowercase(enable bool) AnalyzerPatternProperties
WithLowercase() sets whether text should be lowercased.
func (AnalyzerPattern) WithPattern ¶
func (p AnalyzerPattern) WithPattern(value AnalyzerPatternPattern) AnalyzerPatternProperties
WithPattern() sets the pattern used to tokenize text.
func (AnalyzerPattern) WithStopwords ¶
func (p AnalyzerPattern) WithStopwords(value []string) AnalyzerPatternProperties
WithStopwords() sets the stopwords for the standard analyzer.
func (AnalyzerPattern) WithStopwordsPath ¶
func (p AnalyzerPattern) WithStopwordsPath(value string) AnalyzerPatternProperties
WithStopwordsPath() sets an external stopwords file path.
type AnalyzerPatternFlags ¶
type AnalyzerPatternFlags string
AnalyzerPatternFlags represents Java-compatible regex flags for pattern tokenizers.
var ( AnalyzerPatternFlagsCaseInsensitive AnalyzerPatternFlags = "CASE_INSENSITIVE" AnalyzerPatternFlagsComments AnalyzerPatternFlags = "COMMENTS" AnalyzerPatternFlagsDotAll AnalyzerPatternFlags = "DOTALL" AnalyzerPatternFlagsMultiline AnalyzerPatternFlags = "MULTILINE" AnalyzerPatternFlagsUnicodeCase AnalyzerPatternFlags = "UNICODE_CASE" AnalyzerPatternFlagsUnixLines AnalyzerPatternFlags = "UNIX_LINES" )
type AnalyzerPatternPattern ¶
type AnalyzerPatternPattern string
AnalyzerPatternPattern defines common regex patterns used in pattern-based tokenizers.
var ( AnalyzerPatternPatternNonWord AnalyzerPatternPattern = `\W+` AnalyzerPatternPatternWhitespace AnalyzerPatternPattern = `\s+` AnalyzerPatternPatternComma AnalyzerPatternPattern = `,` AnalyzerPatternPatternPipe AnalyzerPatternPattern = `\|` AnalyzerPatternPatternDot AnalyzerPatternPattern = `\.` AnalyzerPatternPatternCustomWords AnalyzerPatternPattern = `[\s,;:\.\-]+` )
type AnalyzerPatternProperties ¶
type AnalyzerPatternProperties func() map[string]interface{}
type AnalyzerSimple ¶
type AnalyzerSimple func(name string) AnalyzerFunc
type AnalyzerStandard ¶
type AnalyzerStandard func(name string, properties ...AnalyzerStandardProperties) AnalyzerFunc
func (AnalyzerStandard) WithMaxTokenLength ¶
func (s AnalyzerStandard) WithMaxTokenLength(value int) AnalyzerStandardProperties
WithMaxTokenLength() sets the max_token_length for the standard analyzer.
func (AnalyzerStandard) WithStopwords ¶
func (s AnalyzerStandard) WithStopwords(value []string) AnalyzerStandardProperties
WithStopwords() sets the stopwords for the standard analyzer.
func (AnalyzerStandard) WithStopwordsPath ¶
func (s AnalyzerStandard) WithStopwordsPath(value string) AnalyzerStandardProperties
WithStopwordsPath() sets an external stopwords file path.
type AnalyzerStandardProperties ¶
type AnalyzerStandardProperties func() map[string]interface{}
type AnalyzerStop ¶
type AnalyzerStop func(name string, properties ...AnalyzerStopProperties) AnalyzerFunc
func (AnalyzerStop) WithStopwords ¶
func (s AnalyzerStop) WithStopwords(value []string) AnalyzerStopProperties
WithStopwords() sets the stopwords for the standard analyzer.
func (AnalyzerStop) WithStopwordsPath ¶
func (s AnalyzerStop) WithStopwordsPath(value string) AnalyzerStopProperties
WithStopwordsPath() sets an external stopwords file path.
type AnalyzerStopProperties ¶
type AnalyzerStopProperties func() map[string]interface{}
type AnalyzerWhitespace ¶
type AnalyzerWhitespace func(name string) AnalyzerFunc
type Config ¶
type Config struct {
Name string
Definition DefinitionConfig
}
Config{} represents the overall configuration for an Elasticsearch index.
type DefinitionConfig ¶
type DefinitionConfig struct {
Settings *SettingsConfig `json:"settings,omitempty"`
Mappings *MappingsConfig `json:"mappings,omitempty"`
}
DefinitionConfig{} contains the settings and mappings for an Elasticsearch index.
type Fake ¶
type Fake string
var ( FakeEmail Fake = "email" FakeFirstName Fake = "first_name" FakeLastName Fake = "last_name" FakeFullName Fake = "full_name" FakeUsername Fake = "username" FakePhone Fake = "phone" FakeCountry Fake = "country" FakeCity Fake = "city" FakeStreet Fake = "street" FakeZip Fake = "zip" FakeUUID Fake = "uuid" FakeURL Fake = "url" FakeCompany Fake = "company" FakeJobTitle Fake = "job_title" FakeColor Fake = "color" FakeIPv4 Fake = "ipv4" FakeIPv6 Fake = "ipv6" FakeBool Fake = "bool" FakeInt Fake = "int" FakeFloat Fake = "float" FakeDate Fake = "date" FakeTimestamp Fake = "timestamp" FakeParagraph Fake = "paragraph" )
type FakeScaledFloat ¶
type FakeScaledFloat string
var (
FakeScaledFloatFloat FakeScaledFloat = "float"
)
type FieldBoolean ¶
type FieldBoolean func(name string, fake FakeBoolean, properties ...FieldBooleanProperties) FieldFunc
func (FieldBoolean) WithDocValues ¶
func (b FieldBoolean) WithDocValues(enabled bool) FieldBooleanProperties
WithDocValues() adds a "doc_values" property to a boolean field.
func (FieldBoolean) WithIndex ¶
func (b FieldBoolean) WithIndex(enabled bool) FieldBooleanProperties
WithIndex() adds an "index" property to a boolean field.
func (FieldBoolean) WithNullValue ¶
func (b FieldBoolean) WithNullValue(value bool) FieldBooleanProperties
WithNullValue() adds a "null_value" property to a boolean field.
func (FieldBoolean) WithStore ¶
func (b FieldBoolean) WithStore(enabled bool) FieldBooleanProperties
WithStore() adds a "store" property to a boolean field.
type FieldBooleanProperties ¶
type FieldBooleanProperties func() map[string]interface{}
type FieldByte ¶
type FieldByte func(name string, fake FakeByte, properties ...FieldByteProperties) FieldFunc
func (FieldByte) WithCoerce ¶
func (b FieldByte) WithCoerce(enabled bool) FieldByteProperties
WithCoerce() adds a "coerce" property to a byte field.
func (FieldByte) WithDocValues ¶
func (b FieldByte) WithDocValues(enabled bool) FieldByteProperties
WithDocValues() adds a "doc_values" property to a byte field.
func (FieldByte) WithIgnoreMalformed ¶
func (b FieldByte) WithIgnoreMalformed(enabled bool) FieldByteProperties
WithIgnoreMalformed() adds an "ignore_malformed" property to a byte field.
func (FieldByte) WithIndex ¶
func (b FieldByte) WithIndex(enabled bool) FieldByteProperties
WithIndex() adds an "index" property to a byte field.
func (FieldByte) WithNullValue ¶
func (b FieldByte) WithNullValue(value int) FieldByteProperties
WithNullValue() adds a "null_value" property to a byte field.
func (FieldByte) WithStore ¶
func (b FieldByte) WithStore(enabled bool) FieldByteProperties
WithStore() adds a "store" property to a byte field.
type FieldByteProperties ¶
type FieldByteProperties func() map[string]interface{}
type FieldDate ¶
type FieldDate func(name string, fake FakeDates, properties ...FieldDateProperties) FieldFunc
func (FieldDate) WithDocValues ¶
func (d FieldDate) WithDocValues(enabled bool) FieldDateProperties
WithDocValues() adds a "doc_values" property to a date field.
func (FieldDate) WithFormat ¶
func (d FieldDate) WithFormat(value string) FieldDateProperties
WithFormat() adds a "format" property to a date field.
func (FieldDate) WithIgnoreMalformed ¶
func (d FieldDate) WithIgnoreMalformed(enabled bool) FieldDateProperties
WithIgnoreMalformed() adds an "ignore_malformed" property to a date field.
func (FieldDate) WithIndex ¶
func (d FieldDate) WithIndex(enabled bool) FieldDateProperties
WithIndex() adds an "index" property to a date field.
func (FieldDate) WithStore ¶
func (d FieldDate) WithStore(enabled bool) FieldDateProperties
WithStore() adds a "store" property to a date field.
type FieldDateProperties ¶
type FieldDateProperties func() map[string]interface{}
type FieldDouble ¶
type FieldDouble func(name string, fake FakeDouble, properties ...FieldDoubleProperties) FieldFunc
func (FieldDouble) WithCoerce ¶
func (d FieldDouble) WithCoerce(enabled bool) FieldDoubleProperties
WithCoerce() adds a "coerce" property to a double field.
func (FieldDouble) WithDocValues ¶
func (d FieldDouble) WithDocValues(enabled bool) FieldDoubleProperties
WithDocValues() adds a "doc_values" property to a double field.
func (FieldDouble) WithIgnoreMalformed ¶
func (d FieldDouble) WithIgnoreMalformed(enabled bool) FieldDoubleProperties
WithIgnoreMalformed() adds an "ignore_malformed" property to a double field.
func (FieldDouble) WithIndex ¶
func (d FieldDouble) WithIndex(enabled bool) FieldDoubleProperties
WithIndex() adds an "index" property to a double field.
func (FieldDouble) WithNullValue ¶
func (d FieldDouble) WithNullValue(value int) FieldDoubleProperties
WithNullValue() adds a "null_value" property to a double field.
func (FieldDouble) WithStore ¶
func (d FieldDouble) WithStore(enabled bool) FieldDoubleProperties
WithStore() adds a "store" property to a double field.
type FieldDoubleProperties ¶
type FieldDoubleProperties func() map[string]interface{}
type FieldFloat ¶
type FieldFloat func(name string, fake FakeFloats, properties ...FieldFloatProperties) FieldFunc
func (FieldFloat) WithCoerce ¶
func (f FieldFloat) WithCoerce(enabled bool) FieldFloatProperties
WithCoerce() adds a "coerce" property to a float field.
func (FieldFloat) WithDocValues ¶
func (f FieldFloat) WithDocValues(enabled bool) FieldFloatProperties
WithDocValues() adds a "doc_values" property to a float field.
func (FieldFloat) WithIgnoreMalformed ¶
func (f FieldFloat) WithIgnoreMalformed(enabled bool) FieldFloatProperties
WithIgnoreMalformed() adds an "ignore_malformed" property to a float field.
func (FieldFloat) WithIndex ¶
func (f FieldFloat) WithIndex(enabled bool) FieldFloatProperties
WithIndex() adds an "index" property to a float field.
func (FieldFloat) WithNullValue ¶
func (f FieldFloat) WithNullValue(value int) FieldFloatProperties
WithNullValue() adds a "null_value" property to a float field.
func (FieldFloat) WithStore ¶
func (f FieldFloat) WithStore(enabled bool) FieldFloatProperties
WithStore() adds a "store" property to a float field.
type FieldFloatProperties ¶
type FieldFloatProperties func() map[string]interface{}
type FieldHalfFloat ¶
type FieldHalfFloat func(name string, fake FakeHalfFloat, properties ...FieldHalfFloatProperties) FieldFunc
func (FieldHalfFloat) WithCoerce ¶
func (h FieldHalfFloat) WithCoerce(enabled bool) FieldHalfFloatProperties
WithCoerce() adds a "coerce" property to a half_float field.
func (FieldHalfFloat) WithDocValues ¶
func (h FieldHalfFloat) WithDocValues(enabled bool) FieldHalfFloatProperties
WithDocValues() adds a "doc_values" property to a half_float field.
func (FieldHalfFloat) WithIgnoreMalformed ¶
func (h FieldHalfFloat) WithIgnoreMalformed(enabled bool) FieldHalfFloatProperties
WithIgnoreMalformed() adds an "ignore_malformed" property to a half_float field.
func (FieldHalfFloat) WithIndex ¶
func (h FieldHalfFloat) WithIndex(enabled bool) FieldHalfFloatProperties
WithIndex() adds an "index" property to a half_float field.
func (FieldHalfFloat) WithNullValue ¶
func (h FieldHalfFloat) WithNullValue(value int) FieldHalfFloatProperties
WithNullValue() adds a "null_value" property to a half_float field.
func (FieldHalfFloat) WithStore ¶
func (h FieldHalfFloat) WithStore(enabled bool) FieldHalfFloatProperties
WithStore() adds a "store" property to a half_float field.
type FieldHalfFloatProperties ¶
type FieldHalfFloatProperties func() map[string]interface{}
type FieldIP ¶
type FieldIP func(name string, fake FakeIP, properties ...FieldIPProperties) FieldFunc
func (FieldIP) WithDocValues ¶
func (i FieldIP) WithDocValues(enabled bool) FieldIPProperties
WithDocValues() adds a "doc_values" property to an IP field.
func (FieldIP) WithIndex ¶
func (i FieldIP) WithIndex(enabled bool) FieldIPProperties
WithIndex() adds an "index" property to an IP field.
func (FieldIP) WithNullValue ¶
func (i FieldIP) WithNullValue(value string) FieldIPProperties
WithNullValue() adds a "null_value" property to an IP field.
func (FieldIP) WithStore ¶
func (i FieldIP) WithStore(enabled bool) FieldIPProperties
WithStore() adds a "store" property to an IP field.
type FieldIPProperties ¶
type FieldIPProperties func() map[string]interface{}
type FieldInteger ¶
type FieldInteger func(name string, fake FakeInteger, properties ...FieldIntegerProperties) FieldFunc
func (FieldInteger) WithCoerce ¶
func (i FieldInteger) WithCoerce(enabled bool) FieldIntegerProperties
WithCoerce() adds a "coerce" property to an integer field.
func (FieldInteger) WithDocValues ¶
func (i FieldInteger) WithDocValues(enabled bool) FieldIntegerProperties
WithDocValues() adds a "doc_values" property to an integer field.
func (FieldInteger) WithIgnoreMalformed ¶
func (i FieldInteger) WithIgnoreMalformed(enabled bool) FieldIntegerProperties
WithIgnoreMalformed() adds an "ignore_malformed" property to an integer field.
func (FieldInteger) WithIndex ¶
func (i FieldInteger) WithIndex(enabled bool) FieldIntegerProperties
WithIndex() adds an "index" property to an integer field.
func (FieldInteger) WithNullValue ¶
func (i FieldInteger) WithNullValue(value int) FieldIntegerProperties
WithNullValue() adds a "null_value" property to an integer field.
func (FieldInteger) WithStore ¶
func (i FieldInteger) WithStore(enabled bool) FieldIntegerProperties
WithStore() adds a "store" property to an integer field.
type FieldIntegerProperties ¶
type FieldIntegerProperties func() map[string]interface{}
type FieldKeyword ¶
type FieldKeyword func(name string, fake Fake, properties ...FieldKeywordProperties) FieldFunc
func (FieldKeyword) WithDocValues ¶
func (k FieldKeyword) WithDocValues(enabled bool) FieldKeywordProperties
WithDocValues() adds a "doc_values" property to a FieldKeyword.
func (FieldKeyword) WithEagerGlobalOrdinals ¶
func (k FieldKeyword) WithEagerGlobalOrdinals(enabled bool) FieldKeywordProperties
WithEagerGlobalOrdinals() adds an "eager_global_ordinals" property to a FieldKeyword.
func (FieldKeyword) WithIgnoreAbove ¶
func (k FieldKeyword) WithIgnoreAbove(value int) FieldKeywordProperties
WithIgnoreAbove() adds an "ignore_above" property to a FieldKeyword.
func (FieldKeyword) WithIndex ¶
func (k FieldKeyword) WithIndex(enabled bool) FieldKeywordProperties
WithIndex() adds an "index" property to a FieldKeyword.
func (FieldKeyword) WithNormalizer ¶
func (k FieldKeyword) WithNormalizer(value string) FieldKeywordProperties
WithNormalizer() adds a "normalizer" property to a FieldKeyword.
func (FieldKeyword) WithNullValue ¶
func (k FieldKeyword) WithNullValue(value string) FieldKeywordProperties
WithNullValue() adds a "null_value" property to a FieldKeyword.
func (FieldKeyword) WithStore ¶
func (k FieldKeyword) WithStore(enabled bool) FieldKeywordProperties
WithStore() adds a "store" property to a FieldKeyword.
type FieldKeywordProperties ¶
type FieldKeywordProperties func() map[string]interface{}
type FieldLong ¶
type FieldLong func(name string, fake FakeLong, properties ...FieldLongProperties) FieldFunc
func (FieldLong) WithCoerce ¶
func (l FieldLong) WithCoerce(enabled bool) FieldLongProperties
WithCoerce() adds a "coerce" property to a long field.
func (FieldLong) WithDocValues ¶
func (l FieldLong) WithDocValues(enabled bool) FieldLongProperties
WithDocValues() adds a "doc_values" property to a long field.
func (FieldLong) WithIgnoreMalformed ¶
func (l FieldLong) WithIgnoreMalformed(enabled bool) FieldLongProperties
WithIgnoreMalformed() adds an "ignore_malformed" property to a long field.
func (FieldLong) WithIndex ¶
func (l FieldLong) WithIndex(enabled bool) FieldLongProperties
WithIndex() adds an "index" property to a long field.
func (FieldLong) WithNullValue ¶
func (l FieldLong) WithNullValue(value int) FieldLongProperties
WithNullValue() adds a "null_value" property to a long field.
func (FieldLong) WithStore ¶
func (l FieldLong) WithStore(enabled bool) FieldLongProperties
WithStore() adds a "store" property to a long field.
type FieldLongProperties ¶
type FieldLongProperties func() map[string]interface{}
type FieldScaledFloat ¶
type FieldScaledFloat func(name string, fake FakeScaledFloat, properties ...FieldScaledFloatProperties) FieldFunc
func (FieldScaledFloat) WithCoerce ¶
func (s FieldScaledFloat) WithCoerce(enabled bool) FieldScaledFloatProperties
WithCoerce() adds a "coerce" property to a scaled_float field.
func (FieldScaledFloat) WithDocValues ¶
func (s FieldScaledFloat) WithDocValues(enabled bool) FieldScaledFloatProperties
WithDocValues() adds a "doc_values" property to a scaled_float field.
func (FieldScaledFloat) WithIgnoreMalformed ¶
func (s FieldScaledFloat) WithIgnoreMalformed(enabled bool) FieldScaledFloatProperties
WithIgnoreMalformed() adds an "ignore_malformed" property to a scaled_float field.
func (FieldScaledFloat) WithIndex ¶
func (s FieldScaledFloat) WithIndex(enabled bool) FieldScaledFloatProperties
WithIndex() adds an "index" property to a scaled_float field.
func (FieldScaledFloat) WithNullValue ¶
func (s FieldScaledFloat) WithNullValue(value int) FieldScaledFloatProperties
WithNullValue() adds a "null_value" property to a scaled_float field.
func (FieldScaledFloat) WithStore ¶
func (s FieldScaledFloat) WithStore(enabled bool) FieldScaledFloatProperties
WithStore() adds a "store" property to a scaled_float field.
type FieldScaledFloatProperties ¶
type FieldScaledFloatProperties func() map[string]interface{}
type FieldShort ¶
type FieldShort func(name string, fake FakeShort, properties ...FieldShortProperties) FieldFunc
func (FieldShort) WithCoerce ¶
func (s FieldShort) WithCoerce(enabled bool) FieldShortProperties
WithCoerce() adds a "coerce" property to a short field.
func (FieldShort) WithDocValues ¶
func (s FieldShort) WithDocValues(enabled bool) FieldShortProperties
WithDocValues() adds a "doc_values" property to a short field.
func (FieldShort) WithIgnoreMalformed ¶
func (s FieldShort) WithIgnoreMalformed(enabled bool) FieldShortProperties
WithIgnoreMalformed() adds an "ignore_malformed" property to a short field.
func (FieldShort) WithIndex ¶
func (s FieldShort) WithIndex(enabled bool) FieldShortProperties
WithIndex() adds an "index" property to a short field.
func (FieldShort) WithNullValue ¶
func (s FieldShort) WithNullValue(value int) FieldShortProperties
WithNullValue() adds a "null_value" property to a short field.
func (FieldShort) WithStore ¶
func (s FieldShort) WithStore(enabled bool) FieldShortProperties
WithStore() adds a "store" property to a short field.
type FieldShortProperties ¶
type FieldShortProperties func() map[string]interface{}
type FieldText ¶
type FieldText func(name string, fake Fake, properties ...FieldTextProperties) FieldFunc
func (FieldText) WithAnalyzer ¶
func (t FieldText) WithAnalyzer(value string) FieldTextProperties
WithAnalyzer() adds an "analyzer" property to a FieldText.
func (FieldText) WithEagerGlobalOrdinals ¶
func (t FieldText) WithEagerGlobalOrdinals(enabled bool) FieldTextProperties
WithEagerGlobalOrdinals() adds an "eager_global_ordinals" property to a FieldText.
func (FieldText) WithIndex ¶
func (t FieldText) WithIndex(enabled bool) FieldTextProperties
WithIndex() adds an "index" property to a FieldText.
func (FieldText) WithNorms ¶
func (t FieldText) WithNorms(enabled bool) FieldTextProperties
WithNorms() adds a "norms" property to a FieldText.
func (FieldText) WithPositionIncrementGap ¶
func (t FieldText) WithPositionIncrementGap(value int) FieldTextProperties
WithPositionIncrementGap() adds a "position_increment_gap" property to a FieldText.
func (FieldText) WithSearchAnalyzer ¶
func (t FieldText) WithSearchAnalyzer(value string) FieldTextProperties
WithSearchAnalyzer() adds a "search_analyzer" property to a FieldText.
func (FieldText) WithStore ¶
func (t FieldText) WithStore(enabled bool) FieldTextProperties
WithStore() adds a "store" property to a FieldText.
func (FieldText) WithTermVector ¶
func (t FieldText) WithTermVector(value string) FieldTextProperties
WithTermVector() adds a "term_vector" property to a FieldText.
type FieldTextProperties ¶
type FieldTextProperties func() map[string]interface{}
type LocationFromFile ¶
type LocationFromFile func(path string) OriginFunc
type LocationGenerate ¶
type LocationGenerate func(amount int) OriginFunc
type M ¶
type M struct {
Index index
Documents documents
Client searcher
}
M{} represents the migration object that holds information about index and document migration.
func New ¶
func New(cc *elasticsearch.Client) M
New() initializes and returns a new migration object.
func (M) MigrateDown ¶
MigrateDown() performs the "down" migration, which includes deleting documents and the index.
type MappingsConfig ¶
type MappingsConfig struct {
Properties map[string]interface{} `json:"properties,omitempty"`
}
MappingsConfig{} defines the field mappings for an Elasticsearch index, including the types and properties for each field in the index.
type NormalizerCustom ¶
type NormalizerCustom func(name string, properties ...NormalizerCustomProperties) NormalizerFunc
func (NormalizerCustom) WithCharFilter ¶
func (c NormalizerCustom) WithCharFilter(value []NormalizerCustomCharFilter) NormalizerCustomProperties
WithCharFilter() defines a list of character filters for the custom normalizer.
func (NormalizerCustom) WithFilter ¶
func (c NormalizerCustom) WithFilter(value []NormalizerCustomFilter) NormalizerCustomProperties
WithFilter() defines a list of token filters to be used in the custom normalizer.
type NormalizerCustomCharFilter ¶
type NormalizerCustomCharFilter string
var ( NormalizerCustomCharFilterHTMLStrip NormalizerCustomCharFilter = "html_strip" NormalizerCustomCharFilterMapping NormalizerCustomCharFilter = "mapping" NormalizerCustomCharFilterPatternReplace NormalizerCustomCharFilter = "pattern_replace" )
type NormalizerCustomFilter ¶
type NormalizerCustomFilter string
var ( NormalizerCustomFilterArabicNormalization NormalizerCustomFilter = "arabic_normalization" NormalizerCustomFilterASCIIFolding NormalizerCustomFilter = "asciifolding" NormalizerCustomFilterBengaliNormalization NormalizerCustomFilter = "bengali_normalization" NormalizerCustomFilterCJKWidth NormalizerCustomFilter = "cjk_width" NormalizerCustomFilterDecimalDigit NormalizerCustomFilter = "decimal_digit" NormalizerCustomFilterElision NormalizerCustomFilter = "elision" NormalizerCustomFilterGermanNormalization NormalizerCustomFilter = "german_normalization" NormalizerCustomFilterHindiNormalization NormalizerCustomFilter = "hindi_normalization" NormalizerCustomFilterIndicNormalization NormalizerCustomFilter = "indic_normalization" NormalizerCustomFilterLowercase NormalizerCustomFilter = "lowercase" NormalizerCustomFilterPatternReplace NormalizerCustomFilter = "pattern_replace" NormalizerCustomFilterPersianNormalization NormalizerCustomFilter = "persian_normalization" NormalizerCustomFilterSerbianNormalization NormalizerCustomFilter = "serbian_normalization" NormalizerCustomFilterSoraniNormalization NormalizerCustomFilter = "sorani_normalization" NormalizerCustomFilterTrim NormalizerCustomFilter = "trim" NormalizerCustomFilterUppercase NormalizerCustomFilter = "uppercase" )
type NormalizerCustomProperties ¶
type NormalizerCustomProperties func() map[string]interface{}
type NormalizerFunc ¶
type NormalizerFunc func() map[string]interface{}
type OriginFunc ¶
type SettingsConfig ¶
type SettingsConfig struct {
NumberOfShards int `json:"number_of_shards,omitempty"`
NumberOfReplicas int `json:"number_of_replicas,omitempty"`
Analysis *AnalysisConfig `json:"analysis,omitempty"`
}
SettingsConfig{} defines the settings related to an Elasticsearch index, including the number of shards, replicas, and custom analysis configurations.